CustomEmojiFaceData class

Constructors

CustomEmojiFaceData({required String name, required String icon, required List<String> list, bool isEmoji = false})
CustomEmojiFaceData.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String
getter/setter pair
isEmoji ↔ bool
getter/setter pair
list ↔ List<String>
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited